==> jc-1.4.0.tar.gz: soot/jimple/spark/fieldrw/FieldReadTag.c <==
// public class soot.jimple.spark.fieldrw.FieldReadTag

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 617ac82c0bec2dff java_util_Set
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag
// @dep_class 5c6a8447c13f5d0d soot_jimple_spark_fieldrw_FieldReadTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Set
// @dep_header soot_jimple_spark_fieldrw_FieldReadTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Set.h"
#include "soot/jimple/spark/fieldrw/FieldReadTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(java.util.Set)
//

static _jc_linenum _jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$_init$4239edc3ba8b9760[];

static const unsigned char _jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$_init$4239edc3ba8b9760[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$param_types$_init$4239edc3ba8b9760[] = {
	&_jc_java_util_Set$type
};

_jc_method _jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$_init$4239edc3ba8b9760 = {
	.name=			"<init>",
	.signature=		"(Ljava/util/Set;)V",
	.class=			&_jc_soot_jimple_spark_fieldrw_FieldReadTag$type,
	.param_types=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$param_types$_init$4239edc3ba8b9760,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$_init$4239edc3ba8b9760,
	.signature_hash=	_JC_JLONG(0x4239edc3ba8b9760),
	.access_flags=		0,
	.function=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$_init$4239edc3ba8b9760,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$_init$4239edc3ba8b9760
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_fieldrw_FieldReadTag, _init$4239edc3ba8b9760);

void
_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$_init$4239edc3ba8b9760(_jc_env *const env, _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *this, _jc_object *param0)
{
	struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *r0;
	struct _jc_object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(27);				// 0
	_JC_INVOKE_NONVIRTUAL(env, soot_jimple_spark_fieldrw_FieldRWTag, _init$4239edc3ba8b9760, 0, r0, r1);
	_JC_LINE_NUMBER(28);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getName()
//

static _jc_linenum _jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_jimple_spark_fieldrw_FieldReadTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable, soot_jimple_spark_fieldrw_FieldReadTag.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_fieldrw_FieldReadTag, getName$bec186f2ce7e1882);

_jc_java_lang_String$object *
_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *this)
{
	struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(30);				// 0
	return _JC_STRING(env, "FieldReadTag");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$methods[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$_init$4239edc3ba8b9760,
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_2[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882,
	_JC_NULL
};
static _jc_method *_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_41[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$getValue$824c7561d2f47329,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_2,
	[41]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_41
};

// Interface "quick" lookup hash table
static const void *_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	[41]=	&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getValue$824c7561d2f47329
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_13[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_96[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldRWTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[13]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_13,
	[58]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_58,
	[96]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_96,
	[113]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Set",	_JC_JLONG(0x617ac82c0bec2dff) },
	{ "soot/jimple/spark/fieldrw/FieldRWTag",	_JC_JLONG(0x26c009a8a59d47e0) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype _jc_soot_jimple_spark_fieldrw_FieldReadTag$type = {
    .type= {
	.name=			"soot/jimple/spark/fieldrw/FieldReadTag",
	.superclass=		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		15,
		.hash=			_JC_JLONG(0x5c6a8447c13f5d0d),
		.source_file=		"FieldReadTag.java",
		.instance_size=		sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$refs) + sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$methods) / sizeof(*_jc_soot_jimple_spark_fieldrw_FieldReadTag$methods),
		.methods=		_jc_soot_jimple_spark_fieldrw_FieldReadTag$methods,
		.instanceof_hash_table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends) / sizeof(*_jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends),
		.class_depends=		_jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_spark_fieldrw_FieldRWTag= {
	    .getName$bec186f2ce7e1882=			// overridden
		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	    .getValue$824c7561d2f47329=
		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getValue$824c7561d2f47329,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$toString$7ea43b33b80a3070,
	},
	.soot_jimple_spark_fieldrw_FieldReadTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/spark/fieldrw/FieldReadTag.c <==
// public class soot.jimple.spark.fieldrw.FieldReadTag

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 617ac82c0bec2dff java_util_Set
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag
// @dep_class 5c6a8447c13f5d0d soot_jimple_spark_fieldrw_FieldReadTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Set
// @dep_header soot_jimple_spark_fieldrw_FieldReadTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Set.h"
#include "soot/jimple/spark/fieldrw/FieldReadTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(java.util.Set)
//

static _jc_linenum _jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$_init$4239edc3ba8b9760[];

static const unsigned char _jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$_init$4239edc3ba8b9760[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$param_types$_init$4239edc3ba8b9760[] = {
	&_jc_java_util_Set$type
};

_jc_method _jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$_init$4239edc3ba8b9760 = {
	.name=			"<init>",
	.signature=		"(Ljava/util/Set;)V",
	.class=			&_jc_soot_jimple_spark_fieldrw_FieldReadTag$type,
	.param_types=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$param_types$_init$4239edc3ba8b9760,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$_init$4239edc3ba8b9760,
	.signature_hash=	_JC_JLONG(0x4239edc3ba8b9760),
	.access_flags=		0,
	.function=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$_init$4239edc3ba8b9760,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$_init$4239edc3ba8b9760
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_fieldrw_FieldReadTag, _init$4239edc3ba8b9760);

void _JC_JCNI_ATTR
_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$_init$4239edc3ba8b9760(_jc_env *const env, _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *this, _jc_object *param0)
{
	struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *r0;
	struct _jc_object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(27);				// 0
	_JC_INVOKE_NONVIRTUAL(env, soot_jimple_spark_fieldrw_FieldRWTag, _init$4239edc3ba8b9760, 0, r0, r1);
	_JC_LINE_NUMBER(28);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getName()
//

static _jc_linenum _jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_jimple_spark_fieldrw_FieldReadTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable, soot_jimple_spark_fieldrw_FieldReadTag.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_fieldrw_FieldReadTag, getName$bec186f2ce7e1882);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *this)
{
	struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(30);				// 0
	return _JC_STRING(env, "FieldReadTag");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$methods[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$_init$4239edc3ba8b9760,
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_2[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882,
	_JC_NULL
};
static _jc_method *_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_41[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$getValue$824c7561d2f47329,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_2,
	[41]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_bucket_41
};

// Interface "quick" lookup hash table
static const void *_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	[41]=	&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getValue$824c7561d2f47329
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_13[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldReadTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_96[] = {
	&_jc_soot_jimple_spark_fieldrw_FieldRWTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[13]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_13,
	[58]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_58,
	[96]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_96,
	[101]=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Set",	_JC_JLONG(0x617ac82c0bec2dff) },
	{ "soot/jimple/spark/fieldrw/FieldRWTag",	_JC_JLONG(0x26c009a8a59d47e0) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype _jc_soot_jimple_spark_fieldrw_FieldReadTag$type = {
    .type= {
	.name=			"soot/jimple/spark/fieldrw/FieldReadTag",
	.superclass=		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		15,
		.hash=			_JC_JLONG(0x5c6a8447c13f5d0d),
		.source_file=		"FieldReadTag.java",
		.instance_size=		sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$refs) + sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$methods) / sizeof(*_jc_soot_jimple_spark_fieldrw_FieldReadTag$methods),
		.methods=		_jc_soot_jimple_spark_fieldrw_FieldReadTag$methods,
		.instanceof_hash_table=	_jc_soot_jimple_spark_fieldrw_FieldReadTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends) / sizeof(*_jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends),
		.class_depends=		_jc_soot_jimple_spark_fieldrw_FieldReadTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_spark_fieldrw_FieldRWTag= {
	    .getName$bec186f2ce7e1882=			// overridden
		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	    .getValue$824c7561d2f47329=
		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getValue$824c7561d2f47329,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$toString$7ea43b33b80a3070,
	},
	.soot_jimple_spark_fieldrw_FieldReadTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882,
	},
    }
};
